# If a line contains anything other than whitespace, commands or comments,
# then it is interpreted as a rule. A rule is a line of the transition table.
# It defines an action for a given situation (first 2 fields) and has 5 fields:
#
#    state   read   write   move   nextState
#
# We separate the fields with whitespace (as we already did for arguments).
# 'read' and 'write' have to be exactly one symbol. 'move' has to be a number
# (negative numbers move the head to the left). Instead of numbers,
# you can also use one of the following aliases:
#    -1 = {l, L, <}
#     0 = {n, N, s, S, =}
#     1 = {r, R, >}


# Lets define our first turing machine:

#! start s
#! end   e
#! fill  *

# toggle 0 and 1 and move to the right
s	1	0	R	s
s	0	1	R	s
# stop, when the end of the word was reached
s	*	*	N	e

# This turing machine runs over a binary number and flips all bits.
# You can actually execute it. Open Tursi, load this file,
# write something binary onto the tape (use the text field on the right side),
# then execute your machine by clicking the play button (green triangle arrow).


# When writing your own table, keep in mind that the turing machine has
# to be deterministic. All rules must be unique by their first two fields.

